@@ -9,6 +9,8 @@ def build_config() -> dict[str, str]:
 
     All dictionary keys and values are strings, for example ``False`` is
     returned as ``"False"``.
+
+        .. versionadded:: 1.1.0
     """
     return dict(
         # Python settings
@@ -17,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.1.1",
-        meson_version="1.2.1",
-        mesonpy_version="0.14.0",
+        contourpy_version="1.2.0",
+        meson_version="1.2.3",
+        mesonpy_version="0.15.0",
         pybind11_version="2.11.1",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.1.1/.mesonpy-3f9m2zvd/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy-1.1.1/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.2.0/.mesonpy-7c9v2n7x/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy-1.2.0/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.1.1/.mesonpy-3f9m2zvd/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.0/.mesonpy-7c9v2n7x/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
